@@ -1,19 +1,6 @@
 # 引入哈希库
 import hashlib
-import datetime
-from .sqlalchemy import BaseModel, Base
-from sqlalchemy import Column, Integer, String, DATETIME
-from .config_log import config
-
-
-class UrlUuid(Base, BaseModel):
-    # 表的名字:
-    __tablename__ = 'short_urls'
-    __label__ = 'mysql_short_url'
-    __database__ = config(__label__, 'database')
-    id = Column(String(16), primary_key=True)
-    url = Column(String(512))
-    create_time = Column(DATETIME())
+import uuid
 
 
 def get_md5(s):
@@ -63,15 +50,13 @@ def get_url_uuid_list(long_url):
     return uuid_list
 
 
-def get_url_uuid(long_url):
-    uuid_list = get_url_uuid_list(long_url)
-    for uuid in uuid_list:
-        url_uuid = UrlUuid.get_by_id(uuid)
-        if not url_uuid:
-            _now = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-            url_entity = UrlUuid(id=uuid, url=long_url, create_time=_now)
-            UrlUuid.save(url_entity)
-            return uuid
-        if url_uuid.url == long_url:
-            return uuid
-    return None
+namespace = uuid.UUID('6ba7b811-9dad-11d1-80b4-00c04fd430c8')
+
+
+def get_uuid5(short_text):
+    return uuid.uuid5(namespace, short_text)
+
+
+if __name__ == '__main__':
+    r = get_md5('xxx')
+    print(r)
